@@ -4,7 +4,7 @@ import pytest
 
 import dask
 import dask.dataframe as dd
-from dask.dataframe._compat import PANDAS_GT_100, PANDAS_GT_110, PANDAS_GT_120, tm
+from dask.dataframe._compat import PANDAS_GT_110, PANDAS_GT_120, tm
 from dask.dataframe.indexing import _coerce_loc_index
 from dask.dataframe.utils import assert_eq, make_meta
 
@@ -35,32 +35,11 @@ def test_loc():
     assert_eq(d.loc[3:], full.loc[3:])
     assert_eq(d.loc[[5]], full.loc[[5]])
 
-    expected_warning = FutureWarning
-
-    if not PANDAS_GT_100:
-        # removed in pandas 1.0
-        with pytest.warns(expected_warning):
-            assert_eq(d.loc[[3, 4, 1, 8]], full.loc[[3, 4, 1, 8]])
-        with pytest.warns(expected_warning):
-            assert_eq(d.loc[[3, 4, 1, 9]], full.loc[[3, 4, 1, 9]])
-        with pytest.warns(expected_warning):
-            assert_eq(d.loc[np.array([3, 4, 1, 9])], full.loc[np.array([3, 4, 1, 9])])
-
     assert_eq(d.a.loc[5], full.a.loc[5:5])
     assert_eq(d.a.loc[3:8], full.a.loc[3:8])
     assert_eq(d.a.loc[:8], full.a.loc[:8])
     assert_eq(d.a.loc[3:], full.a.loc[3:])
     assert_eq(d.a.loc[[5]], full.a.loc[[5]])
-    if not PANDAS_GT_100:
-        # removed in pandas 1.0
-        with pytest.warns(expected_warning):
-            assert_eq(d.a.loc[[3, 4, 1, 8]], full.a.loc[[3, 4, 1, 8]])
-        with pytest.warns(expected_warning):
-            assert_eq(d.a.loc[[3, 4, 1, 9]], full.a.loc[[3, 4, 1, 9]])
-        with pytest.warns(expected_warning):
-            assert_eq(
-                d.a.loc[np.array([3, 4, 1, 9])], full.a.loc[np.array([3, 4, 1, 9])]
-            )
     assert_eq(d.a.loc[[]], full.a.loc[[]])
     assert_eq(d.a.loc[np.array([])], full.a.loc[np.array([])])
 
@@ -183,12 +162,6 @@ def test_loc2d():
         d.a.loc[d.a % 2 == 0, 3]
 
 
-@pytest.mark.skip(PANDAS_GT_100, reason="Removed in pandas 1.0")
-def test_loc2d_some_missing():
-    with pytest.warns(FutureWarning):
-        assert_eq(d.loc[[3, 4, 3], ["a"]], full.loc[[3, 4, 3], ["a"]])
-
-
 def test_loc2d_with_known_divisions():
     df = pd.DataFrame(
         np.random.randn(20, 5),
